@@ -18,7 +18,6 @@ import unittest
 import warnings
 
 import requests
-import six
 
 from google.cloud._helpers import UTC
 from google.cloud import datastore
@@ -55,9 +54,7 @@ def clone_client(client):
         )
     else:
         return datastore.Client(
-            project=client.project,
-            namespace=client.namespace,
-            _http=client._http,
+            project=client.project, namespace=client.namespace, _http=client._http,
         )
 
 
@@ -70,16 +67,13 @@ def setUpModule():
     else:
         http = requests.Session()  # Un-authorized.
         Config.CLIENT = datastore.Client(
-            project=emulator_dataset,
-            namespace=test_namespace,
-            _http=http,
+            project=emulator_dataset, namespace=test_namespace, _http=http,
         )
 
 
 def tearDownModule():
-    keys = [entity.key for entity in Config.TO_DELETE]
     with Config.CLIENT.transaction():
-        Config.CLIENT.delete_multi(keys)
+        Config.CLIENT.delete_multi(Config.TO_DELETE)
 
 
 class TestDatastore(unittest.TestCase):
@@ -88,8 +82,7 @@ class TestDatastore(unittest.TestCase):
 
     def tearDown(self):
         with Config.CLIENT.transaction():
-            keys = [entity.key for entity in self.case_entities_to_delete]
-            Config.CLIENT.delete_multi(keys)
+            Config.CLIENT.delete_multi(self.case_entities_to_delete)
 
 
 class TestDatastoreAllocateIDs(TestDatastore):
@@ -298,7 +291,7 @@ class TestDatastoreQuery(TestDatastore):
 
         # Fetch characters.
         iterator = query.fetch(limit=limit)
-        page = six.next(iterator.pages)
+        page = next(iterator.pages)
         character_entities = list(page)
         cursor = iterator.next_page_token
         self.assertEqual(len(character_entities), limit)
@@ -446,7 +439,7 @@ class TestDatastoreQuery(TestDatastore):
         iterator = page_query.fetch(limit=limit, offset=offset)
 
         # Fetch characters.
-        page = six.next(iterator.pages)
+        page = next(iterator.pages)
         entities = list(page)
         cursor = iterator.next_page_token
         self.assertEqual(len(entities), limit)
@@ -470,7 +463,7 @@ class TestDatastoreQuery(TestDatastore):
         iterator = page_query.fetch(limit=limit, offset=offset)
 
         # Fetch characters.
-        page = six.next(iterator.pages)
+        page = next(iterator.pages)
         entities = list(page)
         cursor = iterator.next_page_token
         self.assertEqual(len(entities), limit)
